---
title: <span class="badge object-type-scalar"></span> SwedishKrona
---
# <span class="badge object-type-scalar"></span> SwedishKrona

Currency: Swedish Krona (kr)

## Definition

```python
# Currency: Swedish Krona (kr)
SwedishKrona: typing.Literal["currencySEK"] = "currencySEK"
```
